Summary: A GNU set of database routines which use extensible hashing
Name: gdbm
Version: 1.8.0
Release: 36%{?dist}
Source: http://ftp.gnu.org/gnu/gdbm/gdbm-%{version}.tar.gz
# Prevent gdbm from storing uninitialized memory content
# to database files.
# The change allows Valgrind users to debug their packages without
# dealing with gdbm-related noise. It also improves security, as 
# the uninitialized memory might contain sensitive informations 
# from other applications. The patch is taken from Debian.
# See rhbz#4457. (rhbz#572601)
# See http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=208927
Patch0: gdbm-1.8.0-zeroheaders.patch
# Make gdbm buildable.
Patch1: gdbm-1.8.0-fhs.patch
# This patch was merged into gdbm-1.8.3.
Patch3: gdbm-1.8.0-64offset.patch
# Memory leak in gdbm_reorganize(gdb) (rhbz#572598)
# Fixed in gdbm-1.8.3
Patch4: gdbm-1.8.0-memleak.patch
# Make gdbm handle read(2) returning less data than it was asked for.
# http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=274417 (rhbz#572900)
Patch5: gdbm-1.8.0-shortread.patch
License: GPLv2+
URL: http://www.gnu.org/software/gdbm/
Group: System Environment/Libraries
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires: libtool

%description
Gdbm is a GNU database indexing library, including routines which use
extensible hashing.  Gdbm works in a similar way to standard UNIX dbm
routines.  Gdbm is useful for developers who write C applications and
need access to a simple and efficient database or who are building C
applications which will use such a database.

If you're a C developer and your programs need access to simple
database routines, you should install gdbm.  You'll also need to
install gdbm-devel.

%package devel
Summary: Development libraries and header files for the gdbm library
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires(post): info
Requires(preun): info

%description devel
Gdbm-devel contains the development libraries and header files for
gdbm, the GNU database system.  These libraries and header files are
necessary if you plan to do development using the gdbm database.

Install gdbm-devel if you are developing C programs which will use the
gdbm database library.  You'll also need to install the gdbm package.

%prep
%setup -q
%patch0 -p1 -b .zeroheaders
%patch1 -p1 -b .fhs
%patch3 -p1 -b .offset
%patch4 -p1 -b .memleak
%patch5 -p1 -b .shortread

# refresh config.sub, the original one does not recognize "redhat"
# as vendorname:
for f in /usr/share/automake-1.1?/config.sub; do
  :
done
cp -p $f .
libtoolize --force --copy
aclocal
autoconf

%build
%configure --disable-static

# flock does not work on nfs
# fcntl should be used instead of it
# see `man 2 flock`
# rhbz#477300
echo "/* We use fcntl locking (POSIX) instead of flock (BSD) */" >> autoconf.h
echo "#undef HAVE_FLOCK" >> autoconf.h

make

%install
rm -rf ${RPM_BUILD_ROOT}

%makeinstall install-compat

ln -sf gdbm/gdbm.h $RPM_BUILD_ROOT/%{_includedir}/gdbm.h
ln -sf libgdbm.so.2.0.0 $RPM_BUILD_ROOT/%{_libdir}/libgdbm.so

rm -f $RPM_BUILD_ROOT/%{_libdir}/libgdbm.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/gdbm.info.gz %{_infodir}/dir \
      --entry="* gdbm: (gdbm).                   The GNU Database." || :

%preun devel
if [ $1 = 0 ]; then
   /sbin/install-info --delete %{_infodir}/gdbm.info.gz %{_infodir}/dir \
      --entry="* gdbm: (gdbm).                   The GNU Database." || :
fi

%files
%defattr(-,root,root,-)
%doc COPYING NEWS README
%{_libdir}/libgdbm.so.*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libgdbm.so
%{_includedir}/gdbm*
%{_infodir}/*.info*
%{_mandir}/man3/*

%clean
rm -rf ${RPM_BUILD_ROOT}


%changelog

